@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2026 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -57,7 +57,7 @@ OF_APPLICATION_DELEGATE(TableGenerator)
 		_titlecaseTableSize           = SIZE_MAX;
 		_caseFoldingTableSize         = SIZE_MAX;
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -497,17 +497,17 @@ OF_APPLICATION_DELEGATE(TableGenerator)
 	    @"extern \"C\" {\n"
 	    @"#endif\n"
 	    @"extern const OFUnichar *const _Nonnull\n"
-	    @"    _OFUnicodeUppercaseTable[_OFUnicodeUppercaseTableSize] "
-	    @"OF_VISIBILITY_HIDDEN;\n"
+	    @"    _OFUnicodeUppercaseTable[_OFUnicodeUppercaseTableSize]\n"
+	    @"    OF_VISIBILITY_INTERNAL;\n"
 	    @"extern const OFUnichar *const _Nonnull\n"
-	    @"    _OFUnicodeLowercaseTable[_OFUnicodeLowercaseTableSize] "
-	    @"OF_VISIBILITY_HIDDEN;\n"
+	    @"    _OFUnicodeLowercaseTable[_OFUnicodeLowercaseTableSize]\n"
+	    @"    OF_VISIBILITY_INTERNAL;\n"
 	    @"extern const OFUnichar *const _Nonnull\n"
-	    @"    _OFUnicodeTitlecaseTable[_OFUnicodeTitlecaseTableSize] "
-	    @"OF_VISIBILITY_HIDDEN;\n"
+	    @"    _OFUnicodeTitlecaseTable[_OFUnicodeTitlecaseTableSize]\n"
+	    @"    OF_VISIBILITY_INTERNAL;\n"
 	    @"extern const OFUnichar *const _Nonnull\n"
 	    @"    _OFUnicodeCaseFoldingTable[_OFUnicodeCaseFoldingTableSize]\n"
-	    @"    OF_VISIBILITY_HIDDEN;\n"
+	    @"    OF_VISIBILITY_INTERNAL;\n"
 	    @"#ifdef __cplusplus\n"
 	    @"}\n"
 	    @"#endif\n"];
