@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2026 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -529,7 +529,7 @@ OF_ASSUME_NONNULL_END
 
 #import "OFMutableArray.h"
 
-#ifndef NSINTEGER_DEFINED
+#if !defined(NSINTEGER_DEFINED) && !__has_feature(objc_modules)
 /* Required for array literals to work */
 @compatibility_alias NSArray OFArray;
 #endif
