@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2026 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -25,7 +25,7 @@ OF_ASSUME_NONNULL_BEGIN
 #ifdef __cplusplus
 extern "C" {
 #endif
-extern int _OFObject_KeyValueCoding_reference OF_VISIBILITY_HIDDEN;
+extern int _OFObject_KeyValueCoding_reference OF_VISIBILITY_INTERNAL;
 #ifdef __cplusplus
 }
 #endif
