@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2026 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -57,7 +57,7 @@
 # define ioctlsocket(fd, req, arg) IoctlSocket(fd, req, arg)
 # define hstrerror(err) "unknown (no hstrerror)"
 # define SOCKET_ERROR -1
-# if defined(OF_HAVE_THREADS) && !defined(OF_MORPHOS)
+# ifdef OF_HAVE_THREADS
 #  define SocketBase ((struct Library *)OFTLSKeyGet(_OFSocketBaseKey))
 #  ifdef OF_AMIGAOS4
 #   define ISocket ((struct SocketIFace *)OFTLSKeyGet(_OFSocketInterfaceKey))
@@ -79,6 +79,7 @@ typedef uint32_t in_addr_t;
 # define fcntl(fd, cmd, flags) net_fcntl(fd, cmd, flags)
 # define h_errno 0
 # define hstrerror(err) "unknown (no hstrerror)"
+# define ioctlsocket(...) net_ioctl(__VA_ARGS__)
 # define listen(sock, backlog) net_listen(sock, backlog)
 # define poll(fds, nfds, timeout) net_poll(fds, nfds, timeout)
 # define recv(sock, buf, len, flags) net_recv(sock, buf, len, flags)
@@ -101,20 +102,20 @@ OF_ASSUME_NONNULL_BEGIN
 #ifdef __cplusplus
 extern "C" {
 #endif
-extern bool _OFSocketInit(void) OF_VISIBILITY_HIDDEN;
-#if defined(OF_HAVE_THREADS) && defined(OF_AMIGAOS) && !defined(OF_MORPHOS)
-extern void _OFSocketDeinit(void) OF_VISIBILITY_HIDDEN;
+extern bool _OFSocketInit(void) OF_VISIBILITY_INTERNAL;
+#if defined(OF_HAVE_THREADS) && defined(OF_AMIGAOS)
+extern void _OFSocketDeinit(void) OF_VISIBILITY_INTERNAL;
 #endif
-extern int _OFSocketErrNo(void) OF_VISIBILITY_HIDDEN;
+extern int _OFSocketErrNo(void) OF_VISIBILITY_INTERNAL;
 #if !defined(OF_WII) && !defined(OF_NINTENDO_3DS)
 extern int _OFGetSockName(OFSocketHandle sock, struct sockaddr *restrict addr,
-    socklen_t *restrict addrLen) OF_VISIBILITY_HIDDEN;
+    socklen_t *restrict addrLen) OF_VISIBILITY_INTERNAL;
 #endif
 
-#if defined(OF_HAVE_THREADS) && defined(OF_AMIGAOS) && !defined(OF_MORPHOS)
-extern OFTLSKey _OFSocketBaseKey OF_VISIBILITY_HIDDEN;
+#if defined(OF_HAVE_THREADS) && defined(OF_AMIGAOS)
+extern OFTLSKey _OFSocketBaseKey OF_VISIBILITY_INTERNAL;
 # ifdef OF_AMIGAOS4
-extern OFTLSKey _OFSocketInterfaceKey OF_VISIBILITY_HIDDEN;
+extern OFTLSKey _OFSocketInterfaceKey OF_VISIBILITY_INTERNAL;
 # endif
 #endif
 #ifdef __cplusplus
