@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2026 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -34,7 +34,7 @@ OF_ASSUME_NONNULL_BEGIN
 extern "C" {
 #endif
 extern size_t _OFStrFTime(char *buffer, size_t bufferLen, const char *format,
-    struct tm *tm, short tz) OF_VISIBILITY_HIDDEN;
+    struct tm *tm, short tz) OF_VISIBILITY_INTERNAL;
 #ifdef __cplusplus
 }
 #endif
