@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2026 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -26,7 +26,7 @@ OF_ASSUME_NONNULL_BEGIN
 #ifdef __cplusplus
 extern "C" {
 #endif
-extern int _OFString_XMLUnescaping_reference OF_VISIBILITY_HIDDEN;
+extern int _OFString_XMLUnescaping_reference OF_VISIBILITY_INTERNAL;
 #ifdef __cplusplus
 }
 #endif
