@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2026 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -19,13 +19,18 @@
 
 #include "config.h"
 
+#import "macros.h"
+
 #define Class IntuitionClass
 #include <proto/exec.h>
 #undef Class
 
-#import "OFInitializationFailedException.h"
+#include <devices/timer.h>
+#ifdef OF_MORPHOS
+# include <ppcinline/timer.h>
+#endif
 
-#import "macros.h"
+#import "OFInitializationFailedException.h"
 
 #ifdef OF_AMIGAOS4
 extern struct Library *DOSBase;
@@ -35,6 +40,9 @@ struct Library *LocaleBase;
 #ifdef OF_AMIGAOS4
 struct LocaleIFace *ILocale;
 #endif
+struct Device *TimerBase;
+struct Unit *MicroHZUnit;
+static struct timerequest timeRequest;
 
 OF_CONSTRUCTOR()
 {
@@ -55,10 +63,20 @@ OF_CONSTRUCTOR()
 	    GetInterface(LocaleBase, "main", 1, NULL)) == NULL)
 		@throw [OFInitializationFailedException exception];
 #endif
+
+	if (OpenDevice("timer.device", UNIT_MICROHZ,
+	    &timeRequest.tr_node, 0) != 0)
+		@throw [OFInitializationFailedException exception];
+
+	TimerBase = timeRequest.tr_node.io_Device;
+	MicroHZUnit = timeRequest.tr_node.io_Unit;
 }
 
 OF_DESTRUCTOR()
 {
+	if (TimerBase != NULL)
+		CloseDevice(&timeRequest.tr_node);
+
 #ifdef OF_AMIGAOS4
 	if (ILocale != NULL)
 		DropInterface((struct Interface *)ILocale);
