@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2026 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -63,7 +63,7 @@
 #ifdef OF_AMIGAOS
 const char *VER = "$VER: ofhttp " OF_PREPROCESSOR_STRINGIFY(OBJFW_VERSION_MAJOR)
     "." OF_PREPROCESSOR_STRINGIFY(OBJFW_VERSION_MINOR) " (" BUILD_DATE ") "
-    "\xA9 2008-2025 Jonathan Schleifer";
+    "\xA9 2008-2026 Jonathan Schleifer";
 #endif
 
 #define KIBIBYTE 1024
@@ -163,7 +163,7 @@ version(void)
 {
 	[OFStdOut writeFormat: @"ofhttp %@ (ObjFW %@) "
 			       @"<https://objfw.nil.im/>\n"
-			       @"Copyright (c) 2008-2025 Jonathan Schleifer "
+			       @"Copyright (c) 2008-2026 Jonathan Schleifer "
 			       @"<js@nil.im>\n"
 			       @"Licensed under the LGPL 3.0 "
 			       @"<https://www.gnu.org/licenses/lgpl-3.0.html>"
@@ -333,8 +333,9 @@ fileNameFromContentDisposition(OFString *contentDisposition)
 		_method = OFHTTPRequestMethodGet;
 
 		_clientHeaders = [[OFMutableDictionary alloc]
-		    initWithObject: @"OFHTTP"
-			    forKey: @"User-Agent"];
+		    initWithKeysAndObjects:
+		    @"User-Agent", @"OFHTTP",
+		    @"Accept", @"*/*", nil];
 
 		_HTTPClient = [[OFHTTPClient alloc] init];
 		_HTTPClient.delegate = self;
